@@ -51,7 +51,7 @@ class CollectionCloner:
         if self.des_db_name == '':
             logger.error('No des_db_name is found')
         if self.des_col_name == '':
-            logger.error('No des_col is found')
+            logger.error('No des_col_name is found')
         
         try:
             src_client = pymongo.MongoClient('localhost')
@@ -67,7 +67,7 @@ class CollectionCloner:
         if self.des_db_name == '':
             logger.error('No des_db_name is found')
         if self.des_col_name == '':
-            logger.error('No des_col is found')
+            logger.error('No des_col_name is found')
 
         try:
             des_client = pymongo.MongoClient('localhost')
@@ -107,7 +107,7 @@ class CollectionCloner:
         if self.password == '':
             logger.error('No password is found')
         if self.des_col_name == '':
-            logger.error('No des_col is found')
+            logger.error('No des_col_name is found')
         if self.des_ip == '':
             logger.error('No des_ip is found')
 
@@ -145,7 +145,7 @@ class CollectionCloner:
             logger.error('No src_ip is found')
         try:
             src_server = SSHTunnelForwarder(
-                src_ip,
+                self.src_ip,
                 ssh_username=self.user,
                 ssh_password=self.password,
                 remote_bind_address=('127.0.0.1', 27017)
@@ -161,10 +161,10 @@ class CollectionCloner:
             logger.error(e)
 
         # Destinatoion 
-        if des_db_name == '':
+        if self.des_db_name == '':
             logger.error('No des_db_name is found')
-        if des_col == '':
-            logger.error('No des_col is found')
+        if self.des_col_name == '':
+            logger.error('No des_col_name is found')
 
         des_client = pymongo.MongoClient('localhost')
         try:
@@ -214,7 +214,7 @@ class CollectionCloner:
         if self.password == '':
             logger.error('No password is found')
         if self.des_col_name == '':
-            logger.error('No des_col is found')
+            logger.error('No des_col_name is found')
         if self.des_ip == '':
             logger.error('No des_ip is found')
 
